==> busy-7.x-1.1.tar.gz: busy/templates/html.tpl.php <==
<?php
// $Id: html.tpl.php,v 1.1.2.1 2011/01/29 17:48:51 aschiwi Exp $

/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * Variables:
 * - $css: An array of CSS files for the current page.
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $rdf_namespaces: All the RDF namespace prefixes used in the HTML document.
 * - $grddl_profile: A GRDDL profile allowing agents to extract the RDF data.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $page_top: Initial markup from any modules that have altered the
 *   page. This variable should always be output first, before all other dynamic
 *   content.
 * - $page: The rendered page content.
 * - $page_bottom: Final closing markup from any modules that have altered the
 *   page. This variable should always be output last, after all other dynamic
 *   content.
 * - $classes String of classes that can be used to style contextually through
 *   CSS.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 */
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML+RDFa 1.0//EN"
  "http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language; ?>" version="XHTML+RDFa 1.0" dir="<?php print $language->dir; ?>"
  <?php print $rdf_namespaces; ?>>
  <head profile="<?php print $grddl_profile; ?>">
    <?php print $head; ?>
    <title><?php print $head_title; ?></title>
    <?php print $styles; ?>
    <?php print $scripts; ?>
  </head>
  <body class="<?php print $classes; ?>" <?php print $attributes;?>>
    <div id="wrapper">
      <div id="wrapper-inner-top">
        <div id="wrapper-inner-bottom">
          <div id="wrapper-inner-color-bar">
            <div id="wrapper-inner-shadow-over-left">
              <div id="wrapper-inner-shadow-over-right">
                <div id="wrapper-inner-shadow-repeated-left">
                  <div id="wrapper-inner-shadow-top-left">
                    <div id="wrapper-inner-shadow-color-bar-left">
                      <div id="wrapper-inner-shadow-middle-left">       
                        <div id="wrapper-inner-shadow-bottom-left">
                          <div id="wrapper-inner-shadow-repeated-right">
                            <div id="wrapper-inner-shadow-top-right">
                              <div id="wrapper-inner-shadow-color-bar-right">
                                <div id="wrapper-inner-shadow-middle-right">       
                                  <div id="wrapper-inner-shadow-bottom-right">
                                    <div id="skip-link">
                                      <a href="#main-content"><?php print t('Skip to main content'); ?></a>
                                    </div>
                                    <?php print $page_top; ?>
                                    <?php print $page; ?>
                                    <?php print $page_bottom; ?>																		
                                  </div>
                                </div>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
							 <div id="page_postfooter">Designed by <a href="http://www.undpaul.de" title="undpaul Drupal development" rel="external">undpaul Drupal development</a></div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </body>
</html>

==> busy-7.x-1.3.tar.gz: busy/templates/html.tpl.php <==
<?php
// $Id: html.tpl.php,v 1.1.2.2 2011/01/30 13:41:35 stborchert Exp $

/**
 * @file
 * Default theme implementation to display the basic html structure of a single
 * Drupal page.
 *
 * Variables:
 * - $css: An array of CSS files for the current page.
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $rdf_namespaces: All the RDF namespace prefixes used in the HTML document.
 * - $grddl_profile: A GRDDL profile allowing agents to extract the RDF data.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $page_top: Initial markup from any modules that have altered the
 *   page. This variable should always be output first, before all other dynamic
 *   content.
 * - $page: The rendered page content.
 * - $page_bottom: Final closing markup from any modules that have altered the
 *   page. This variable should always be output last, after all other dynamic
 *   content.
 * - $classes String of classes that can be used to style contextually through
 *   CSS.
 *
 * @see template_preprocess()
 * @see template_preprocess_html()
 * @see template_process()
 */
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML+RDFa 1.0//EN"
  "http://www.w3.org/MarkUp/DTD/xhtml-rdfa-1.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language; ?>" version="XHTML+RDFa 1.0" dir="<?php print $language->dir; ?>"
  <?php print $rdf_namespaces; ?>>
  <head profile="<?php print $grddl_profile; ?>">
    <?php print $head; ?>
    <title><?php print $head_title; ?></title>
    <?php print $styles; ?>
    <?php print $scripts; ?>
  </head>
  <body class="<?php print $classes; ?>" <?php print $attributes;?>>
    <div id="wrapper">
      <div id="wrapper-inner-top">
        <div id="wrapper-inner-bottom">
          <div id="wrapper-inner-color-bar">
            <div id="wrapper-inner-shadow-over-left">
              <div id="wrapper-inner-shadow-over-right">
                <div id="wrapper-inner-shadow-repeated-left">
                  <div id="wrapper-inner-shadow-top-left">
                    <div id="wrapper-inner-shadow-color-bar-left">
                      <div id="wrapper-inner-shadow-middle-left">       
                        <div id="wrapper-inner-shadow-bottom-left">
                          <div id="wrapper-inner-shadow-repeated-right">
                            <div id="wrapper-inner-shadow-top-right">
                              <div id="wrapper-inner-shadow-color-bar-right">
                                <div id="wrapper-inner-shadow-middle-right">       
                                  <div id="wrapper-inner-shadow-bottom-right">
                                    <div id="skip-link">
                                      <a href="#main-content"><?php print t('Skip to main content'); ?></a>
                                    </div>
                                    <?php print $page_top; ?>
                                    <?php print $page; ?>
                                    <?php print $page_bottom; ?>																		
                                  </div>
                                </div>
                              </div>
                            </div>
                          </div>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
							         <div id="page_postfooter">Built by <a href="http://www.undpaul.de" title="undpaul Drupal development" rel="external">undpaul Drupal development</a></div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </body>
</html>
